@@ -29,31 +29,14 @@ from checkbox.contrib import bpickle_registry
 
 from checkbox.lib.config import Config
 from checkbox.lib.environ import get_variable
+from checkbox.lib.safe import safe_make_directory
+from checkbox.lib.text import split
 
 from checkbox.plugin import PluginManager
 from checkbox.reactor import Reactor
 from checkbox.registry import RegistryManager
 
 
-def parse_string(options):
-    args = []
-    while True:
-        options = options.strip()
-        if not options:
-            break
-
-        index = 0
-        while index < len(options) \
-              and (not options[index].isspace() \
-                  or options[index - 1] == "\\"):
-           index += 1
-
-        args.append(options[:index])
-        options = options[index:]
-
-    return args
-
-
 class Application(object):
 
     reactor_factory = Reactor
@@ -105,9 +88,13 @@ class ApplicationManager(object):
         return parser.parse_args(args)
 
     def create_application(self, args=sys.argv):
+        # Create data directory
+        data_directory = get_variable("CHECKBOX_DATA", ".")
+        safe_make_directory(data_directory)
+
         # Prepend environment options
         string_options = get_variable("CHECKBOX_OPTIONS", "")
-        args[:0] = parse_string(string_options)
+        args[:0] = split(string_options)
         (options, args) = self.parse_options(args)
 
         log_level = logging.getLevelName(options.log_level.upper())
@@ -134,14 +121,16 @@ class ApplicationManager(object):
             sys.stderr.write(_("Missing configuration file as argument.\n"))
             sys.exit(1)
 
-        config_file = posixpath.expanduser(args[1])
-        config = Config(config_file, options.config)
+        config = Config()
+        config_filename = posixpath.expanduser(args[1])
+        config.read_filename(config_filename)
+        config.read_configs(options.config)
 
         section_name = "checkbox/plugins/client_info"
         section = config.get_section(section_name)
         if not section:
             section = config.add_section(section_name)
-        section.set("name", posixpath.basename(config.path) \
+        section.set("name", posixpath.basename(args[1]) \
             .replace(".ini", ""))
         section.set("version", config.get_defaults().version)
 
