@@ -26,8 +26,7 @@ class DmiInfo(Plugin):
         self._manager.reactor.call_on("report", self.report)
 
     def report(self):
-        self._manager.reactor.fire("report-dmi",
-            self._manager.registry.dmi)
+        self._manager.reactor.fire("report-dmi", self._manager.registry.dmi)
 
 
 factory = DmiInfo
