@@ -24,7 +24,7 @@ from checkbox.plugin import Plugin
 
 class PersistInfo(Plugin):
 
-    # E-mail address used to sign in to Launchpad.
+    # Filename where to persist information
     filename = Path(default="%(checkbox_data)s/plugins.bpickle")
 
     def register(self, manager):
@@ -32,10 +32,8 @@ class PersistInfo(Plugin):
 
         self.persist = None
 
-        for (rt, rh) in [
-             ("gather", self.gather),
-             ("stop", self.stop)]:
-            self._manager.reactor.call_on(rt, rh)
+        self._manager.reactor.call_on("gather", self.gather, -1000)
+        self._manager.reactor.call_on("stop", self.stop, 1000)
 
     def gather(self):
         self.persist = Persist(self.filename)
